`timescale 1ns / 1ps

// (c) Copyright 2009 by Texas Instruments Inc.  All rights reserved.

//------------------------------------------------------------------------------
// xds100v2_cpld.v
//
// CPLD code for the XDS100v2 emulator.  
//
// Note: Compiled with version 10.1 of the Xilinx ISE WebPack available 
//       from the Xilinx web site:  www.xilinx.com
//------------------------------------------------------------------------------

module xds100v2_cpld(
    input  TMS,        // FTDI chip TMS      Standard JTAG TMS
    input  TDI,        // FTDI chip TDI      Standard JTAG TDI
    output TDO,        // FTDI chip TDO      Standard JTAG TDO
    input  TCK,        // FTDI chip TCK      Standard JTAG TCLK
    input  TRST_N,     // FTDI chip GPIOL0   Standard JTAG TRSTn
    input  EMU_EN,     // FTDI chip GPIOL1   Enable output of the EMU0/1 pins
    input  EMU0,       // FTDI chip GPIOL2   EMU0 pin output
    output RTCK,       // FTDI chip GPIOL3   TCLK Return from target
    input  SRST_N_OUT, // FTDI chip GPIOH0   System Reset output
    output SRST_N_IN,  // FTDI chip GPIOH1   System Reset input
    output PWR_DET,    // FTDI chip GPIOH2   Power Loss detect 
    input  PWR_RST,    // FTDI chip GPIOH3   Power Loss reset
    input  EMU1,       // FTDI chip GPIOH4   EMU1 pin output
    output CBL_DIS,    // FTDI chip GPIOH5   Cable Disconnect detect
    input  LOOPBACK,   // FTDI chip GPIOH6   Loopback mode request
    input  RESERVED,   // FTDI chip GPIOH7   (reserved for future use)
    inout  T_TMS,      // Target TMS         Standard JTAG TMS
    output T_TDI,      // Target TDI         Standard JTAG TDI
    input  T_TDO,      // Target TDO         Standard JTAG TDO
    output T_TCK,      // Target TCK         Standard JTAG TCLK
    inout  T_EMU0,     // Target EMU0        EMU0 pin output
    inout  T_EMU1,     // Target EMU1        EMU1 pin output
    output T_TRST_N,   // Target TRSTn       Standard JTAG TRSTn
    inout  T_SRST_N,   // Target SRSTn       System Reset
    input  T_TVD,      // Target TVD         Target Voltage Detect
    input  T_RTCK,     // Target RTCK        TCLK Return from target
    input  T_CBL_DIS,  // Target CBL_DIS     Cable Disconnect detect
    output SHDN_N,     // Power Down output  Power Down the TVD follower  
    input  SUSPEND_N,  // FTDI chip SUSPEND  USB Suspend
    input  PWREN_N     // FTDI chip PWREN    USB Power Enable (unused)
);

// PIN LOCATION CONSTRAINTS
//
//synthesis attribute PIN_ASSIGN of TMS is "P6"
//synthesis attribute PIN_ASSIGN of TDI is "P12"
//synthesis attribute PIN_ASSIGN of TDO is "P8"
//synthesis attribute PIN_ASSIGN of TCK is "P13"
//synthesis attribute PIN_ASSIGN of TRST_N is "P5"
//synthesis attribute PIN_ASSIGN of EMU_EN is "P3"
//synthesis attribute PIN_ASSIGN of EMU0 is "P2"
//synthesis attribute PIN_ASSIGN of RTCK is "P1"
//synthesis attribute PIN_ASSIGN of SRST_N_OUT is "P44"
//synthesis attribute PIN_ASSIGN of SRST_N_IN is "P43"
//synthesis attribute PIN_ASSIGN of PWR_DET is "P41"
//synthesis attribute PIN_ASSIGN of PWR_RST is "P40"
//synthesis attribute PIN_ASSIGN of EMU1 is "P38"
//synthesis attribute PIN_ASSIGN of CBL_DIS is "P37"
//synthesis attribute PIN_ASSIGN of LOOPBACK is "P36"
//synthesis attribute PIN_ASSIGN of RESERVED is "P34"
//synthesis attribute PIN_ASSIGN of T_TMS is "P33"
//synthesis attribute PIN_ASSIGN of T_TDI is "P30"
//synthesis attribute PIN_ASSIGN of T_TDO is "P28"
//synthesis attribute PIN_ASSIGN of T_TCK is "P27"
//synthesis attribute PIN_ASSIGN of T_EMU0 is "P20"
//synthesis attribute PIN_ASSIGN of T_EMU1 is "P19"
//synthesis attribute PIN_ASSIGN of T_TRST_N is "P31"
//synthesis attribute PIN_ASSIGN of T_SRST_N is "P21"
//synthesis attribute PIN_ASSIGN of T_TVD is "P16"
//synthesis attribute PIN_ASSIGN of T_RTCK is "P18"
//synthesis attribute PIN_ASSIGN of T_CBL_DIS is "P29"
//synthesis attribute PIN_ASSIGN of SHDN_N is "P14"
//synthesis attribute PIN_ASSIGN of SUSPEND_N is "P39"
//synthesis attribute PIN_ASSIGN of PWREN is "P42"
 
// IO STANDARD CONSTRAINTS
//
//synthesis attribute IOSTANDARD of TMS is "LVCMOS33"
//synthesis attribute IOSTANDARD of TDI is "LVCMOS33"
//synthesis attribute IOSTANDARD of TDO is "LVCMOS33"
//synthesis attribute IOSTANDARD of TCK is "LVCMOS33"
//synthesis attribute IOSTANDARD of TRST_N is "LVCMOS33"
//synthesis attribute IOSTANDARD of EMU_EN is "LVCMOS33"
//synthesis attribute IOSTANDARD of EMU0 is "LVCMOS33"
//synthesis attribute IOSTANDARD of RTCK is "LVCMOS33"
//synthesis attribute IOSTANDARD of SRST_N_OUT is "LVCMOS33"
//synthesis attribute IOSTANDARD of SRST_N_IN is "LVCMOS33"
//synthesis attribute IOSTANDARD of PWR_DET is "LVCMOS33"
//synthesis attribute IOSTANDARD of PWR_RST is "LVCMOS33"
//synthesis attribute IOSTANDARD of EMU1 is "LVCMOS33"
//synthesis attribute IOSTANDARD of CBL_DIS is "LVCMOS33"
//synthesis attribute IOSTANDARD of LOOPBACK is "LVCMOS33"
//synthesis attribute IOSTANDARD of RESERVED is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TMS is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TDI is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TDO is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TCK is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_EMU0 is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_EMU1 is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TRST_N is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_SRST_N is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_TVD is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_RTCK is "LVCMOS33"
//synthesis attribute IOSTANDARD of T_CBL_DIS is "LVCMOS33"
//synthesis attribute IOSTANDARD of SHDN_N is "LVCMOS33"
//synthesis attribute IOSTANDARD of SUSPEND_N is "LVCMOS33"
//synthesis attribute IOSTANDARD of PWREN is "LVCMOS33"

// OPEN DRAIN CONSTRAINTS
//
//synthesis attribute OPEN_DRAIN of CBL_DIS is "TRUE"
//synthesis attribute OPEN_DRAIN of T_EMU0 is "TRUE"
//synthesis attribute OPEN_DRAIN of T_EMU1 is "TRUE"
//synthesis attribute OPEN_DRAIN of T_SRST_N is "TRUE"

// Registers and Internal Signals
reg  OE_REG;

// Capture Target Power Loss
always @(posedge PWR_RST or negedge T_TVD)
begin
    if (T_TVD == 1'b0)
        OE_REG = 1'b0;
    else if (PWR_RST == 1'b1)
        OE_REG = 1'b1;
end

// Target Output Buffering & Voltage Translation
assign T_TCK     = (OE_REG & !LOOPBACK) ? TCK : 1'bz;
assign T_TMS     = (OE_REG & !LOOPBACK) ? TMS : 1'bz;
assign T_TDI     = (OE_REG & !LOOPBACK) ? TDI : 1'bz;
assign T_TRST_N  = (OE_REG & !LOOPBACK) ? TRST_N : 1'bz;
assign T_SRST_N  = (SRST_N_OUT & OE_REG & !LOOPBACK) ? 1'b0 : 1'bz;
assign T_EMU0    = (EMU0 & !(EMU_EN & OE_REG) & !LOOPBACK) ? 1'b0 : 1'bz;
assign T_EMU1    = (EMU1 & !(EMU_EN & OE_REG) & !LOOPBACK) ? 1'b0 : 1'bz;

// FTDI Chip Inputs
assign RTCK      = (!LOOPBACK) ? T_RTCK : TCK;
assign TDO       = (!LOOPBACK) ? T_TDO : TDI;
assign SRST_N_IN = (!LOOPBACK) ? T_SRST_N : SRST_N_OUT;
assign PWR_DET   = (!LOOPBACK) ? OE_REG : 1'b1;
assign CBL_DIS   = (!LOOPBACK) ? T_CBL_DIS : 1'b0;

// Power Down the Target Voltage follower when in USB Suspend mode
assign SHDN_N = SUSPEND_N;

endmodule

// End of File
